
Gunlink
=======

   
.. image:: https://img.shields.io/badge/version-1.0.0-blue
   :target: https://img.shields.io/badge/version-1.0.0-blue
   :alt: Version
 
.. image:: https://img.shields.io/badge/python-3.9-blue
   :target: https://img.shields.io/badge/python-3.9-blue
   :alt: Python-Version
 
.. image:: https://img.shields.io/github/issues/Brijeshkrishna/gunshot
   :target: https://img.shields.io/github/issues/Brijeshkrishna/gunshot
   :alt: issues
 
.. image:: https://img.shields.io/pypi/status/pw-gen
   :target: https://img.shields.io/pypi/status/pw-gen
   :alt: PyPI - Status
 
.. image:: https://img.shields.io/github/license/lunAr-creator/pw-gen
   :target: https://img.shields.io/github/license/lunAr-creator/pw-gen
   :alt: License
 

| A package that allows to handle URL


Installation
------------

Requests is available on PyPI:

.. code-block::

   $ python -m pip install gunlink


or , simply

.. code-block::

   $ pip install gunlink

Gunshot officially supports Python 2.7 & 3.6+.

Cloning the repository
----------------------

.. code-block::

   git clone https://github.com/Brijeshkrishna/gunlink.git

How to use:
-----------

.. code-block::

   >>> from gunlink import link
   >>> gun = link('https://github.com/Brijeshkrishna')
   >>> gun.is_valid_link
   True


License
-------

| Gunshot is licensed and distributed under the MIT license.  `Contact us <mailto:brijeshkrishnaga@gmail.com>`_  if you're looking for an exception to the terms.

Contributors
------------

| If want to Contributor to gunshot contact me .

